@@ -48,6 +48,11 @@ contains all data items from the gene record.
 The parser will report error & line number if input data does not conform to the
 NCBI Entrez Gene genome annotation file format.
 
+Note that it is possible to provide reading of all NCBI's ASN.1-formatted
+files through simple variations of the Entrez Gene parser (I need more
+investigation to be sure, but at least the sequence parser is a very simple
+variation on Entrez Gene parser and works well).
+
 It took the parser version 1.0 11 minutes to parse the human genome Entrez Gene
 file on one 2.4 GHz Intel Xeon processor.  The addition of validation and error
 reporting in 1.03 and handling of new Entrez Gene format slowed the parser down
@@ -102,7 +107,7 @@ use strict;
 use Carp qw(carp croak);
 use vars qw ($VERSION);
 
-$VERSION = '1.07';
+$VERSION = '1.09';
 
 =head2 new
 
@@ -220,9 +225,11 @@ sub input_file
 {
   my ($self, $filename) = @_;
   # in case user's Perl system can't handle large file. Assuming Unix, otherwise raise error
-  open($self->{fh}, $filename) ||
-  ($! =~ /too large/i && open($self->{fh}, "cat $filename |")) ||
+  local *IN; # older styled code to enable module to work with perl 5.005_03
+  open(*IN, $filename) ||
+  ($! =~ /too large/i && open(*IN, "cat $filename |")) ||
     croak "can't open $filename! -- $!\n";
+  $self->{fh} = *IN;
   $self->{filename} = $filename;
   $self->{linenumber} = 0; # reset line number
 }
