@@ -82,7 +82,7 @@ use Bio::ASN1::EntrezGene;
 use Bio::Index::AbstractSeq;
 
 @ISA = qw(Bio::Index::AbstractSeq);
-$VERSION = '1.07';
+$VERSION = '1.09';
 
 sub _version
 {
@@ -150,5 +150,37 @@ sub fetch_hash
   }
 }
 
+=head2 _file_handle
+
+  Title   : _file_handle
+  Usage   : $fh = $index->_file_handle( INT )
+  Function: Returns an open filehandle for the file
+            index INT.  On opening a new filehandle it
+            caches it in the @{$index->_filehandle} array.
+            If the requested filehandle is already open,
+            it simply returns it from the array.
+  Example : $fist_file_indexed = $index->_file_handle( 0 );
+  Returns : ref to a filehandle
+  Args    : INT
+  Notes   : This function is copied from Bio::Index::Abstract. Once that module
+              changes file handle code like I do below to fit perl 5.005_03, this
+              sub would be removed from this module
+
+=cut
+
+sub _file_handle {
+	my( $self, $i ) = @_;
+
+	unless ($self->{'_filehandle'}[$i]) {
+		my @rec = $self->unpack_record($self->db->{"__FILE_$i"})
+		  or $self->throw("Can't get filename for index : $i");
+		my $file = $rec[0];
+		local *FH;
+		open *FH, $file or $self->throw("Can't read file '$file' : $!");
+		$self->{'_filehandle'}[$i] = *FH; # Cache filehandle
+	}
+	return $self->{'_filehandle'}[$i];
+}
+
 1;
 
